summaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/include
diff options
context:
space:
mode:
authorRene Sapiens2011-01-18 04:19:03 +0100
committerOmar Ramirez Luna2011-02-05 03:12:07 +0100
commitb4da7fc381c51d42c231f97de912b89dbabe8928 (patch)
treebb34871696f7b51faf209c711a884cfa173cee45 /drivers/staging/tidspbridge/include
parentstaging: tidspbridge: remove code referred by OPT_ZERO_COPY_LOADER (diff)
downloadkernel-qcow2-linux-b4da7fc381c51d42c231f97de912b89dbabe8928.tar.gz
kernel-qcow2-linux-b4da7fc381c51d42c231f97de912b89dbabe8928.tar.xz
kernel-qcow2-linux-b4da7fc381c51d42c231f97de912b89dbabe8928.zip
staging: tidspbridge: set1 remove hungarian from structs
hungarian notation will be removed from the elements inside structures, the next varibles will be renamed: dw_api_reg_base api_reg_base dw_brd_state brd_state dw_chnl_buf_size chnl_buf_size dw_chnl_offset chnl_offset dw_cmd cmd dw_core_pm_base core_pm_base dw_dsp_base dsp_base dw_dsp_base_va dsp_base_va dw_dsp_bufs dsp_bufs dw_dsp_buf_size dsp_buf_size dw_dsp_clk_m2_base dsp_clk_m2_base dw_dsp_ext_base_addr dsp_ext_base_addr dw_dsp_phys_addr_offset dsp_phys_addr_offset dw_dsp_start_add dsp_start_add dw_err_mask err_mask dw_gpp_base_pa gpp_base_pa dw_api_clk_base api_clk_base dw_api_reg_base api_reg_base dw_arg arg dw_arg1 arg1 dw_arg2 arg2 dw_chnl_buf_size chnl_buf_size Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Armando Uribe <x0095078@ti.com> Signed-off-by: Omar Ramirez Luna <omar.ramirez@ti.com>
Diffstat (limited to 'drivers/staging/tidspbridge/include')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/_chnl_sm.h2
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/cfgdefs.h10
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/chnldefs.h2
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/cmmdefs.h8
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dbdefs.h8
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/dspapi-ioctl.h4
6 files changed, 17 insertions, 17 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/_chnl_sm.h b/drivers/staging/tidspbridge/include/dspbridge/_chnl_sm.h
index 8a22317e5b5c..14b0567e5314 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/_chnl_sm.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/_chnl_sm.h
@@ -171,7 +171,7 @@ struct chnl_irp {
u8 *host_user_buf;
/* Buffer to be filled/emptied. (System) */
u8 *host_sys_buf;
- u32 dw_arg; /* Issue/Reclaim argument. */
+ u32 arg; /* Issue/Reclaim argument. */
u32 dsp_tx_addr; /* Transfer address on DSP side. */
u32 byte_size; /* Bytes transferred. */
u32 buf_size; /* Actual buffer size when allocated. */
diff --git a/drivers/staging/tidspbridge/include/dspbridge/chnldefs.h b/drivers/staging/tidspbridge/include/dspbridge/chnldefs.h
index 8f8f9ece8d49..2cc27b5bcd0f 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/chnldefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/chnldefs.h
@@ -57,7 +57,7 @@ struct chnl_ioc {
u32 byte_size; /* Bytes transferred. */
u32 buf_size; /* Actual buffer size in bytes */
u32 status; /* Status of IO completion. */
- u32 dw_arg; /* User argument associated with pbuf. */
+ u32 arg; /* User argument associated with pbuf. */
};
#endif /* CHNLDEFS_ */
diff --git a/drivers/staging/tidspbridge/include/dspbridge/cmmdefs.h b/drivers/staging/tidspbridge/include/dspbridge/cmmdefs.h
index e748ba8d6cab..943d91f809e3 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/cmmdefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/cmmdefs.h
@@ -54,9 +54,9 @@ struct cmm_seginfo {
u32 dw_seg_base_pa; /* Start Phys address of SM segment */
/* Total size in bytes of segment: DSP+GPP */
u32 ul_total_seg_size;
- u32 dw_gpp_base_pa; /* Start Phys addr of Gpp SM seg */
+ u32 gpp_base_pa; /* Start Phys addr of Gpp SM seg */
u32 ul_gpp_size; /* Size of Gpp SM seg in bytes */
- u32 dw_dsp_base_va; /* DSP virt base byte address */
+ u32 dsp_base_va; /* DSP virt base byte address */
u32 ul_dsp_size; /* DSP seg size in bytes */
/* # of current GPP allocations from this segment */
u32 ul_in_use_cnt;
@@ -79,8 +79,8 @@ struct cmm_info {
/* XlatorCreate attributes */
struct cmm_xlatorattrs {
u32 ul_seg_id; /* segment Id used for SM allocations */
- u32 dw_dsp_bufs; /* # of DSP-side bufs */
- u32 dw_dsp_buf_size; /* size of DSP-side bufs in GPP bytes */
+ u32 dsp_bufs; /* # of DSP-side bufs */
+ u32 dsp_buf_size; /* size of DSP-side bufs in GPP bytes */
/* Vm base address alloc'd in client process context */
void *vm_base;
/* dw_vm_size must be >= (dwMaxNumBufs * dwMaxSize) */
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dbdefs.h b/drivers/staging/tidspbridge/include/dspbridge/dbdefs.h
index 38fffebd0c0c..6ba66c500e79 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dbdefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dbdefs.h
@@ -244,9 +244,9 @@ struct dsp_cbdata {
/* The dsp_msg structure */
struct dsp_msg {
- u32 dw_cmd;
- u32 dw_arg1;
- u32 dw_arg2;
+ u32 cmd;
+ u32 arg1;
+ u32 arg2;
};
/* The dsp_resourcereqmts structure for node's resource requirements */
@@ -368,7 +368,7 @@ struct dsp_processorinfo {
/* Error information of last DSP exception signalled to the GPP */
struct dsp_errorinfo {
- u32 dw_err_mask;
+ u32 err_mask;
u32 dw_val1;
u32 dw_val2;
u32 dw_val3;
diff --git a/drivers/staging/tidspbridge/include/dspbridge/dspapi-ioctl.h b/drivers/staging/tidspbridge/include/dspbridge/dspapi-ioctl.h
index 8ad9ace1a82a..bd3f885dbe65 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/dspapi-ioctl.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/dspapi-ioctl.h
@@ -68,7 +68,7 @@ union trapped_args {
struct {
void *hprocessor;
- u32 dw_cmd;
+ u32 cmd;
struct dsp_cbdata __user *pargs;
} args_proc_ctrl;
@@ -293,7 +293,7 @@ union trapped_args {
u8 *pbuffer;
u32 dw_bytes;
u32 dw_buf_size;
- u32 dw_arg;
+ u32 arg;
} args_strm_issue;
struct {
diff --git a/drivers/staging/tidspbridge/include/dspbridge/cfgdefs.h b/drivers/staging/tidspbridge/include/dspbridge/cfgdefs.h
index 0589a0a80f50..f7c105af3da9 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/cfgdefs.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/cfgdefs.h
@@ -43,18 +43,18 @@ struct cfg_hostres {
* dw_mem_base + this offset */
/*
* Info needed by NODE for allocating channels to communicate with RMS:
* dw_chnl_offset: Offset of RMS channels. Lower channels are
* reserved.
* dw_chnl_buf_size: Size of channel buffer to send to RMS
* dw_num_chnls: Total number of channels
* (including reserved).
*/
- u32 dw_chnl_offset;
- u32 dw_chnl_buf_size;
+ u32 chnl_offset;
+ u32 chnl_buf_size;
u32 dw_num_chnls;
void __iomem *dw_per_base;
u32 dw_per_pm_base;
- u32 dw_core_pm_base;
+ u32 core_pm_base;
void __iomem *dw_dmmu_base;
};
@@ -43,18 +43,18 @@ struct cfg_hostres {
/*
* Info needed by NODE for allocating channels to communicate with RMS:
- * dw_chnl_offset: Offset of RMS channels. Lower channels are
+ * chnl_offset: Offset of RMS channels. Lower channels are
* reserved.
@@ -43,18 +43,18 @@ struct cfg_hostres {
* reserved.
- * dw_chnl_buf_size: Size of channel buffer to send to RMS
+ * chnl_buf_size: Size of channel buffer to send to RMS
* dw_num_chnls: Total number of channels
* (including reserved).